@@ -80,6 +80,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
 
             use std::env;
             use tokio::task;
+            use tokio::time::interval;
             use checkout_core::cloud_pubsub;
             use checkout_core::dropshot;
             use checkout_core::dropshot::endpoint;
@@ -143,8 +144,12 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             ) {
                 task::spawn(async move {
                     let subscription = internal_ctx.payment_processing_subscription.clone();
-                    while subscription.client().is_running() {
+                    let mut intv = interval(Duration::from_secs(5));
+
+                    loop {
+                        intv.tick().await;
                         println!("pulling payment processing messages");
+
                         match subscription.get_messages::<Message>().await {
                             Ok(messages) => {
                                 for (result, ack_id) in messages {
